module NextcallerClient

  def self.prepare_json_data(data)
    begin
      return data.to_json
    rescue ArgumentError, TypeError
      return data
    end
  end

  def self.to_json(data)
    begin
      return JSON.parse(data)
    rescue ArgumentError, TypeError
      return data
    end
  end

  def self.default_handle_response(resp, response_format='json')
    return JSON.parse(resp.body) if response_format == 'json'
    return Nokogiri::XML(resp.body) if response_format == 'xml'
    resp
  end

  #Validate phone format
  def self.validate_phone(value, length=DEFAULT_PHONE_LENGTH)
    unless value
      raise ArgumentError, 'Invalid phone number: %s. Phone cannot be blank.' % value
    end
    if value.is_a? Integer
      value = value.to_s
    end
    unless value.is_a? String
      raise ArgumentError, 'Invalid phone number: %s. Phone cannot be type of %s.' % [value, value.class]
    end
    unless value.length == length
      raise ArgumentError, 'Invalid phone number: %s. Phone should has length %s.' % [value, length]
    end
    unless value =~ /^[0-9]+$/
      raise ArgumentError, 'Invalid phone number: %s. Phone should consists of only digits.' % value
    end
  end

  #Validate response format
  def self.validate_format(response_format)
    unless RESPONSE_FORMATS.include? response_format
      raise ArgumentError, 'Unsupported format: %s. Supported formats are: %s' % [response_format, RESPONSE_FORMATS]
    end
  end

  #Prepare url from path and params
  def self.prepare_url(path, url_params={})
    url = '%s%s' % [FULL_URL, path]
    unless url.end_with?('/')
      url += '/'
    end
    unless url_params.empty?
      url_params_str = url_params.collect { |k, v| "#{CGI::escape(k.to_s)}=#{CGI::escape(v.to_s)}" }.join('&')
      url += '?' + url_params_str
    end
    url
  end

  def self.prepare_url_for_test(auth, path)
    return Regexp.new 'https://%s:%s@%s%s*' %[auth[:username], auth[:password], BASE_URL, path]
  end

end
